# Changelog

## 6.2.0a1 (2026-01-15)


Bug fixes:

- Prepare release.
  [maurits]


## 6.1.3 (2025-10-02)


Bug fixes:

- Prepare release.
  [maurits]


## 6.1.2 (2025-06-20)


Bug fixes:

- Prepare release.
  [maurits]


## 6.1.1 (2025-03-25)


Bug fixes:

- Prepare release.
  [maurits]


## 6.1.1rc2 (2025-03-21)


Bug fixes:

- Prepare release.
  [maurits]


## 6.1.1rc1 (2025-03-14)


Bug fixes:

- Release 6.1.1rc1.
  [maurits]


## 6.1.0 (2025-02-07)


Bug fixes:

- Release 6.1.0.
  [maurits]


## 6.1.0rc1 (2025-01-31)


Bug fixes:

- Release 6.1.0rc1.
  [maurits]


## 6.1.0b2 (2024-12-19)


Bug fixes:

- Release 6.1.0b2.
  [maurits]


## 6.1.0b1 (2024-10-31)


Breaking changes:

- Require Python 3.10 as minimum.
  [maurits]

New features:

- Add dependency on `plone.classicui` distribution.
  [maurits]


## 6.1.0a5 (2024-09-05)


Bug fixes:

- Release 6.1.0a5.
  [maurits]


## 6.1.0a4 (2024-08-01)

Bug fixes:

- Release 6.1.0a4.
  [maurits]


## 6.1.0a3 (2024-04-26)


Bug fixes:

- Release 6.1.0a3.
  [maurits]


## 6.1.0a2 (2024-02-27)


Bug fixes:

- Release 6.1.0a2.
  [maurits]


## 6.1.0a1 (2024-01-26)

New features:

- Depend on plone.app.discussion here, this makes it an core addon. [jensens]

- Depend on plone.app.multilingual here, this makes it an core addon. [jensens]


## 6.0.7 (2023-09-14)

Bug fixes:

- Release 6.0.7.
  [maurits]


## 6.0.6 (2023-06-22)

Bug fixes:

- Release 6.0.6.
  [maurits]


## 6.0.5 (2023-05-25)

Bug fixes:

- Release 6.0.5.
  [maurits]


## 6.0.4 (2023-04-21)

Bug fixes:

- Release 6.0.4.
  [maurits]


## 6.0.3 (2023-03-23)

Bug fixes:

- Release 6.0.3.
  [maurits]


## 6.0.2 (2023-02-23)


Bug fixes:

- Release 6.0.2.
  [maurits]


## 6.0.1 (2023-01-30)


Bug fixes:

- Release 6.0.1.
  [maurits]


## 6.0.0 (2022-12-12)

Bug fixes:

- Release 6.0.0 final.
  [maurits]


## 6.0.0rc2 (2022-12-05)

Bug fixes:

- Release 6.0.0rc2.
  [maurits]

Internal:

- Improve metadata on pypi.org
  [ericof]


## 6.0.0rc1 (2022-11-18)

Bug fixes:

- Release 6.0.0rc1.
  [maurits]


## 6.0.0b3 (2022-10-04)

Bug fixes:

- Release 6.0.0b3.
  [maurits]


## 6.0.0b2 (2022-09-10)

Breaking changes:

- Officially drop Python 3.7 support and add 3.10 support.
  Currently everything still work in 3.7, but beta 2 is the last release where this is the case.
  [maurits]


## 6.0.0b1 (2022-07-23)

Bug fixes:

- Release 6.0.0b1.
  [maurits]


## 6.0.0a6 (unreleased)

Bug fixes:

- Release 6.0.0a6.
  [maurits]


## 6.0.0a5 (2022-06-24)

Bug fixes:

- Release 6.0.0a5.
  [maurits]


## 6.0.0a4 (2022-04-08)

New features:

- Depend on ``plone.volto``.
  [maurits]


## 6.0.0a3 (2022-01-28)

Bug fixes:

- Release 6.0.0a3.
  [maurits]


## 6.0.0a2 (2021-12-03)

Bug fixes:

- Release 6.0.0a2.
  [maurits]


## 6.0.0a1 (2021-10-16)

Bug fixes:

- Release 6.0.0a1.dev1.
  Update: accidentally released as 6.0.0a1.
  [maurits]


## 6.0.0a1.dev0 (2021-09-15)

Breaking changes:

- Remove ``archetypes`` extra in ``setup.py``.
  [jensens]

- Drop Python 2 support.
  [jensens]

Misc:

- Create internal release on dist.plone.org.  [maurits]

- Move ``setup.py`` metadata to ``setup.cfg``.
  [jensens]


## 5.2.5 (2021-07-31)

Bug fixes:

- Release Plone 5.2.5 final
  [maurits]


## 5.2.4 (2021-02-19)

Bug fixes:

- Release Plone 5.2.4 final
  [maurits]

- Removed ``plone.app.dexterity`` from dependencies.
  It is already required by ``Products.CMFPlone``.
  [maurits]


## 5.2.3 (2020-10-30)

Bug fixes:

- Release Plone 5.2.3 final
  [maurits]


## 5.2.2 (2020-06-28)

New features:

- Release Plone 5.2.2 final
  [maurits]


## 5.2.1 (2019-12-02)

New features:

- Release Plone 5.2.1 final
  [esteele]



## 5.2.0 (2019-07-10)

New features:

- Release Plone 5.2 final
  [esteele]


## 5.2rc5 (2019-06-27)

New features:

- Release Plone 5.2rc5
  [esteele]


## 5.2rc4 (2019-06-19)

New features:

- Release Plone 5.2rc4
  [esteele]


## 5.2rc3 (2019-05-04)

New features:

- Release Plone 5.2rc3
  [esteele]


## 5.2rc2 (2019-03-21)

Bug fixes:

- Release Plone 5.2rc2
  [esteele]

## 5.2rc1 (2019-03-04)

New features:

- Release Plone 5.2rc1
  [esteele]


## 5.2b1 (2019-02-13)

New features:

- Add plone.restapi as a dependency.
  [timo]


## 5.2a2 (2018-12-28)

New features:

- Release Plone 5.2a2
  [esteele]


## 5.2a1 (2018-11-08)

New features:

- Release Plone 5.2a1
  [esteele]


## 5.1.4 (2018-10-01)

New features:

- Release Plone 5.1.4
  [esteele]


## 5.1.3 (2018-06-21)

New features:

- Release Plone 5.1.3
  [esteele]


## 5.1.2 (2018-04-08)

New features:

- Release Plone 5.1.2
  [esteele]


## 5.1.1 (2018-03-10)

New features:

- Release Plone 5.1.1
  [esteele]


## 5.1.0 (2018-02-05)

New features:

- Release Plone 5.1
  [esteele]


## 5.1rc2 (2017-11-26)

New features:

- Release Plone 5.1rc2
  [esteele]

## 5.1rc1 (2017-09-10)

New features:

- Release Plone 5.1rc1



## 5.1b4 (2017-07-03)

New features:

- Release Plone 5.1b4
  [esteele]

Bug fixes:

- Add link to Plone.com and tweak intro
  [tkimnguyen]

## 5.1b3 (2017-04-02)

New features:

- Release Plone 5.1b3
  [esteele]


## 5.1b2 (2017-02-20)

New features:

- Release Plone 5.1b2
  [esteele]


## 5.1b1 (2017-02-20)

Breaking changes:

- Remove plone.app.openid from core, still available as addon package.
  [jensens]

New features:

- Release Plone 5.1b1
  [esteele]

Bug fixes:

- Be sure to require archetypes.multilingual
  even if it's not required as a dependency of plone.app.multilingual.
  [davisagli]


## 5.1a2 (2016-08-19)

New:

- Release Plone 5.1a2
  [esteele]


## 5.1a1 (2016-03-31)

New:

- Release Plone 5.1a1
  [esteele]

## 5.0.2 (2016-01-08)

New:

- Release Plone 5.0.2
  [esteele]


## 5.0.1 (2015-12-17)

- Release Plone 5.0.1
  [esteele]


## 5.0 (2015-09-27)

- Release Plone 5.0
  [esteele]


## 5.0rc3 (2015-09-21)

- Release Plone 5.0rc3
  [esteele]


## 5.0rc2 (2015-09-11)

- Release Plone 5.0rc2
  [esteele]


## 5.0rc1 (2015-09-08)

- Release Plone 5.0rc1
  [esteele]


## 5.0b4 (2015-08-23)

- Release Plone 5.0b4
  [esteele]


## 5.0b3 (2015-07-20)

- Release Plone 5.0b3
  [esteele]

## 5.0b2 (2015-05-27)

- Release Plone 5.0b2
  [esteele]


## 5.0b1 (2015-03-26)

- Release Plone 5.0b1
  [esteele]


## 5.0a3 (2014-11-01)

- Release Plone 5.0a3
  [esteele]


## 5.0a2 (2014-04-20)

- Move plone.app.theming dependency into Products.CMFPlone.
  [esteele]


## 4.3.4 (2014-10-22)
  - Release Plone 4.3.4 [esteele]


## 4.3.3 (2014-02-19)

  - Release Plone 4.3.3 [esteele]

## 4.3.2 (2013-08-14)

  - Release Plone 4.3.2 [esteele]


## 4.3.1 (2013-05-30)

- Release Plone 4.3.1
  [esteele]


## 4.3 (2013-04-06)

- Release Plone 4.3
  [esteele]


## 4.3b2 (2013-01-17)

- Release Plone 4.3b2
  [esteele]


## 4.3b1 (2013-01-01)

- Release Plone 4.3b1
  [esteele]


## 4.3a2 (2012-10-18)

- Release Plone 4.3a2
  [esteele]


## 4.3a1 (2012-08-31)

- Release Plone 4.3a1
  [esteele]


## 4.2.1 (2012-08-11)

- Release Plone 4.2.1
  [esteele]


## 4.2 (2012-06-29)

- Release Plone 4.2
  [esteele]


## 4.2rc2 (2012-05-31)

- Release Plone 4.2rc2
  [esteele]

- Add explicit dependencies on some `zope.app` libraries, to ensure they
  stay included during the 4.2 series.
  [hannosch]


## 4.2rc1 (2012-05-07)

- Release Plone 4.2rc1
  [esteele]


## 4.2b2 (2012-02-09)

- Release Plone 4.2b2
  [esteele]


## 4.2b1 (2011-12-05)

- Release Plone 4.2b1
  [esteele]

## 4.2a2 (2011-08-25)

- Release Plone 4.2a2
  [esteele]

## 4.2a1 (2011-08-08)

- Release Plone 4.2a1
  [esteele]

## 4.1 (2011-07-12)

- Release Plone 4.1 final
  [esteele]

## 4.1rc3 (2011-06-02)

- Release Plone 4.1rc3
  [esteele]

## 4.1rc2 (2011-05-21)

- Release Plone 4.1rc2
  [esteele]


## 4.1rc1 (2011-05-20)

- Release Plone 4.1rc1
  [esteele]

## 4.1b2 (2011-04-06)

- Release Plone 4.1b2
  [esteele]

- Depend on wicked now that Products.CMFPlone doesn't.
  [davisagli]

## 4.1b1 (2011-03-04)

- Release Plone 4.1b1
  [esteele]

## 4.1a3 (2011-02-14)

- Release Plone 4.1a3
  [esteele]

## 4.1a2 (2011-02-10)

- Include plone.app.caching as an optional, shipped add-on.
  [esteele]

## 4.1a1 (2011-01-18)

- Separate `Products.CMFPlone` from the `Plone` egg.
  [elro]
